GroupKind

Enum GroupKind 

#[non_exhaustive]
pub enum GroupKind { Arm(Arm), Gripper(Gripper), Generic(Generic), }
Sum type of every group variant the robot can hold.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Arm(Arm)

Articulated arm.



Gripper(Gripper)

Single-motor gripper.



Generic(Generic)

Generic catch-all group.

Implementations

Source

impl GroupKind

pub fn as_arm(&self) -> Option<&Arm>

Downcast to Arm.

pub fn as_arm_mut(&mut self) -> Option<&mut Arm>

Downcast to Arm mutably.

pub fn as_gripper(&self) -> Option<&Gripper>

Downcast to Gripper.

pub fn as_gripper_mut(&mut self) -> Option<&mut Gripper>

Downcast to Gripper mutably.

pub fn as_generic(&self) -> Option<&Generic>

Downcast to Generic.

pub fn as_generic_mut(&mut self) -> Option<&mut Generic>

Downcast to Generic mutably.

pub fn inner(&self) -> &MotorGroup

Borrow the underlying MotorGroup regardless of variant.

pub fn inner_mut(&mut self) -> &mut MotorGroup

Borrow mutably regardless of variant.

pub fn name(&self) -> &str

Group name (delegated to the inner MotorGroup).

pub fn bus_name(&self) -> &str

Bus name (delegated).

pub fn enable_all(&mut self) -> Result<(), Error>

Enable all motors in this group (delegated).

pub fn disable_all(&mut self) -> Result<(), Error>

Disable all motors in this group (delegated).

pub fn refresh_all(&mut self) -> Result<(), Error>

Send a state-refresh query to every motor in this group (delegated).

pub fn set_mode(&mut self, mode: CommandKind) -> Result<(), Error>

Set the persistent control mode on every motor in this group (delegated).