pub enum OpeningDirection {
IncreasingPosition,
DecreasingPosition,
}Expand description
Whether increasing raw motor position increases or decreases gripper opening.
Variants
IncreasingPosition
Increasing raw motor position moves the gripper toward fully open.
DecreasingPosition
Decreasing raw motor position moves the gripper toward fully open.