pub struct BusPoller { /* private fields */ }Expand description
Registers multiple bus fds and waits for any to become readable within a
deadline. Buses with no raw_fd cannot be registered and must be polled
out-of-band.
Implementations
Sourceimpl BusPoller
impl BusPoller
Sourcepub fn with_capacity(n: usize) -> Result<Self, TransportError>
pub fn with_capacity(n: usize) -> Result<Self, TransportError>
Construct a poller with capacity for n simultaneous ready buses.
Sourcepub fn register(&self, token: Token, fd: RawFd) -> Result<(), TransportError>
pub fn register(&self, token: Token, fd: RawFd) -> Result<(), TransportError>
Register a fd under a token.
Sourcepub fn deregister(&self, fd: RawFd) -> Result<(), TransportError>
pub fn deregister(&self, fd: RawFd) -> Result<(), TransportError>
Deregister a fd; call when the bus is going away.